"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.withOneTrust = void 0;
const analytics_consent_tools_1 = require("@segment/analytics-consent-tools");
const onetrust_api_1 = require("../lib/onetrust-api");
/**
 *
 * @param analyticsInstance - An analytics instance. Either `window.analytics`, or the instance returned by `new AnalyticsBrowser()` or `AnalyticsBrowser.load({...})`
 * @param settings - Optional settings for configuring your OneTrust wrapper
 */
const withOneTrust = (analyticsInstance, settings = {}) => {
    const registerOnConsentChanged = async (onCategoriesChangedCb) => {
        await (0, analytics_consent_tools_1.resolveWhen)(() => (0, onetrust_api_1.getOneTrustGlobal)() !== undefined, 500);
        (0, onetrust_api_1.getOneTrustGlobal)().OnConsentChanged((event) => {
            const normalizedCategories = (0, onetrust_api_1.getNormalizedCategoriesFromGroupIds)(event.detail);
            onCategoriesChangedCb(normalizedCategories);
        });
    };
    return (0, analytics_consent_tools_1.createWrapper)({
        shouldLoad: async () => {
            await (0, analytics_consent_tools_1.resolveWhen)(() => {
                const oneTrustGlobal = (0, onetrust_api_1.getOneTrustGlobal)();
                return (oneTrustGlobal !== undefined &&
                    Boolean((0, onetrust_api_1.getConsentedGroupIds)().length) &&
                    oneTrustGlobal.IsAlertBoxClosed());
            }, 500);
        },
        getCategories: () => {
            const results = (0, onetrust_api_1.getNormalizedCategoriesFromGroupData)();
            return results;
        },
        registerOnConsentChanged: settings.disableConsentChangedEvent
            ? undefined
            : registerOnConsentChanged,
        integrationCategoryMappings: settings.integrationCategoryMappings,
    })(analyticsInstance);
};
exports.withOneTrust = withOneTrust;
//# sourceMappingURL=wrapper.js.map